@@ -4,7 +4,7 @@ from .hubspot import HEADERS
 from . import object_properties
 
 
-def search_contacts_by_property_value(property_name, property_value, property_names=None, after=None):
+def search_contacts_by_property_value(property_name, property_value, property_names=None, after=None, sorts=[]):
   filters = [
       {
           'propertyName': property_name,
@@ -12,20 +12,20 @@ def search_contacts_by_property_value(property_name, property_value, property_na
           'value': property_value
       }
   ]
-  return search_contacts(property_names, filters, after)
+  return search_contacts(property_names, filters, after, sorts)
 
 
-def search_contacts_by_property_known(property_name, property_names, after=None):
+def search_contacts_by_property_known(property_name, property_names, after=None, sorts=[]):
   filters = [
       {
           'propertyName': property_name,
           'operator': 'HAS_PROPERTY'
       }
   ]
-  return search_contacts(property_names, filters, after)
+  return search_contacts(property_names, filters, after, sorts)
 
 
-def search_contacts_by_property_less_than(property_name, property_value, property_names, after=None):
+def search_contacts_by_property_less_than(property_name, property_value, property_names, after=None, sorts=[]):
   filters = [
       {
           'propertyName': property_name,
@@ -33,10 +33,10 @@ def search_contacts_by_property_less_than(property_name, property_value, propert
           'value': property_value
       }
   ]
-  return search_contacts(property_names, filters, after)
+  return search_contacts(property_names, filters, after, sorts)
 
 
-def search_contacts_by_property_greater_than(property_name, property_value, property_names, after=None):
+def search_contacts_by_property_greater_than(property_name, property_value, property_names, after=None, sorts=[]):
   filters = [
       {
           'propertyName': property_name,
@@ -44,10 +44,10 @@ def search_contacts_by_property_greater_than(property_name, property_value, prop
           'value': property_value
       }
   ]
-  return search_contacts(property_names, filters, after)
+  return search_contacts(property_names, filters, after, sorts)
 
 
-def search_contacts_by_property_values(property_name, property_values, property_names, after=None):
+def search_contacts_by_property_values(property_name, property_values, property_names, after=None, sorts=[]):
   filters = [
       {
           'propertyName': property_name,
@@ -55,10 +55,10 @@ def search_contacts_by_property_values(property_name, property_values, property_
           'values': property_values
       }
   ]
-  return search_contacts(property_names, filters, after)
+  return search_contacts(property_names, filters, after, sorts)
 
 
-def search_contacts(property_names, filters, after=None):
+def search_contacts(property_names, filters, after=None, sorts=[]):
   post_url = f"{BASE_URL}crm/v3/objects/contacts/search"
   if after:
     post_url = f"{post_url}?after={after}"
@@ -68,7 +68,7 @@ def search_contacts(property_names, filters, after=None):
               'filters': filters
           }
       ],
-      'sorts': [],
+      'sorts': sorts,
       'properties': property_names,
       'limit': 100
   }
